function f_mod = adjust_phase(f,g_left,g_right)

  % Input
  % f: signal (size N)
  % g_left, g_right: two smaller signals

  % Output
  % f_mod: the signal f, multiplied by a phase of the form
  %         phase[k] = exp(i*(a+b*k/N))
  % where a and b are chosen so that the left part of f_mod is
  % aligned in phase with g_left and the right part is aligned
  % with g_right

  % size of the signals
  N = numel(f) ;
  N_left = numel(g_left) ;
  N_right = numel(g_right) ;

  if (N_left>=N) || (N_right>=N)
     error('adjust_phase.m : g_left or g_right is larger than f.') ;
  end

  f_left = f(1:N_left) ; % left part of f
  alpha_left = angle(sum(g_left .* conj(f_left))) ;
  i_left = (N_left-1) / 2 ; % median index of the left part

  f_right = f(end-N_right+1:end) ; % right part of f
  alpha_right = angle(sum(g_right .* conj(f_right))) ;
  i_right = N - (N_right+1)/2 ; % median index of the right part

  % add a multiple of 2*pi so that abs(alpha_left-alpha_right)
  % is minimal
  alpha_right = alpha_left + mod(alpha_right- ...
                              alpha_left+pi,2*pi)-pi ;
  
  % multiply f by a phase which is equal to alpha_left in i_left and
  % to alpha_right in i_right
  f_mod = f .* exp(i*(alpha_left + (alpha_right-alpha_left) ...
				   * ([0:N-1]-i_left) ...
				   /(i_right-i_left))) ;
