function [psi_low,psi_high] = compute_low_and_high(psi,alpha,a,exp_decay) ;

  % Computes psi_low and psi_high:
  %    psi_low(j,om) = psi(j,om) * exp(-alpha*om*a^(j-1))
  %    psi_high(j,om) = psi(j,om) * exp(alpha*om*a^(j-1))

  % Inputs
  % psi: wavelets
  % alpha: parameter in the definition of psi_low and psi_high
  % a: dilation factor
  % exp_decay: whether the wavelets decrease exponentially or not (in
  %            the latter case, a truncation must be performed)

  % Outputs
  % psi_low, psi_high

  nbf = size(psi,1) ;
  N = size(psi,2) ;

  oms_low = a.^[0:nbf-1]' * [0:N-1] ;
  if exp_decay.bool
     oms_high = oms_low ;
  else
    % truncation in case the decrease is not exponential
    oms_high = zeros(nbf,N) ;
    for s=1:nbf
      ind = exp_decay.cutoff(s) ;
      oms_high(s,:) = a^(s-1) * (ind-abs([0:N-1]-ind)) ;
    end
  end

  oms_low = alpha * oms_low ;
  oms_high = alpha * oms_high ;
  psi_low = psi .* exp(-oms_low) ;
  psi_high = psi .* exp(min(oms_high,20)) ; % the min(...,20) is there to
                                            % avoid numerical errors when
                                            % multiplying a very large number
                                            % by a very small one
  
