function fpsi_low_est = estimate(S,psi_low,psi_high, ...
				 fpsi_low,fpsi_high,i_min) ;

  % If f star psi_low(s,:) and f star psi_high(s,:) have been computed
  % for all s greater than some S, then this function returns an
  % estimation of f star psi_low(S,:)

  % Inputs
  % S : the index at which the estimation must be performed
  % psi_low, psi_high : wavelets used in the reconstruction
  % fpsi_low, fpsi_high : the f star psi_low and f star psi_high
  % i_min : the size of the support of psi_low(S,:) (in Fourier)

  % Output
  % fpsi_low_est : the estimated fpsi_low(S,:)


  % The estimated function is the one that minimizes
  %    sum_(s>S) ||fpsi_low_est star psi_low(s,:) - ...
  %	             fpsi_low(s,:) star psi_low(S,:)||_2^2 + ...
  %              ||fpsi_low_est star psi_high(s,:) - ...
  %	             fpsi_high(s,:) star psi_low(S,:)||_2^2

  N = size(psi_low,2) ;

  div = sum(abs(psi_high(S+1:end,:)).^2,1) + ...
	sum(abs(psi_low(S+1:end,:)).^2,1) ;
  div = div + (abs(div) < 1e-12) ;

  psi_high_c = bsxfun(@rdivide,conj(psi_high(S+1:end,:)),div) ;
  psi_low_c  = bsxfun(@rdivide,conj(psi_low(S+1:end,:)),div) ;
  
  psi_high_c(:,min(i_min,N/2+1)+1:end) = 0 ;
  psi_low_c(:,min(i_min,N/2+1)+1:end) = 0 ;
  
  fpsi_low_f = fft(fpsi_low(S+1:end,:),[],2) ;
  fpsi_high_f = fft(fpsi_high(S+1:end,:),[],2) ;
  
  fpsi_low_est = ifft(psi_low(S,:) .* ...
		      (sum(psi_high_c .* fpsi_high_f,1) + ...
		       sum(psi_low_c .* fpsi_low_f,1))) ;
