function [ind,err_min,product] = eval_prod_ref(sq_mod,al,true_prod)

  % Compute the value of the correct regularization parameter to use
  % in eval_prod, by testing several values on an example where the
  % ground true product is known and keeping the best value

  % Inputs
  % sq_mod: squared (noisy) modulus of (f star psi(j,:))
  % al: real number such that
  %     psi_low(j,om) = psi(j,om) * exp(-alpha*om)
  %     psi_high(j,om) = psi(j,om) * exp(alpha*om)
  % true_prod: true value of
  %            (f star psi_low(j,:)) x conj(f star psi_high(j,:))
	 
  % Ouput
  % ind: best regularization parameter


  N = numel(sq_mod) ;

  % Dichotomy search
  i_inf = -N/2 ; i_sup = 0 ;
  ind = -N/4 ;
  prec = 4 ;

  while (i_sup-i_inf>-i_sup/50)
   
    % List of values to test
    i_test = i_inf + [0:prec] * (i_sup-i_inf) / prec ;
    
    for s=1:(prec+1)
	product = eval_prod(sq_mod,al,i_test(s)) ;
	err(s) = norm(true_prod-product,2) ;
    end

    % Return the value for which the error is minimal
    [err_min,i_min] = min(err) ;
    i_inf = i_test(max(1,i_min-1)) ;
    i_sup = i_test(min(prec+1,i_min+1)) ;
    ind = i_test(i_min) ;
    
  end

product = eval_prod(sq_mod,al,ind) ;
